@@ -1,4 +1,4 @@
-# Copyright 2021 Q-CTRL. All rights reserved.
+# Copyright 2022 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -20,6 +20,7 @@ import uuid
 from typing import Optional
 
 import numpy as np
+from qctrlcommons.preconditions import check_argument
 
 PAULI_X = np.array([[0, 1], [1, 0]], dtype=complex)
 PAULI_Y = np.array([[0, -1j], [1j, 0]], dtype=complex)
@@ -35,7 +36,7 @@ def display_bloch_spheres_and_correlations(
     visualizer_js: Optional[str] = None,
 ):
     r"""
-    Visualizes a trajectory of two-qubit states.
+    Visualize a trajectory of two-qubit states.
 
     This function requires IPython, and you must run it from a Jupyter
     notebook. By default, it requires an Internet connection to fetch the
@@ -268,7 +269,7 @@ def display_bloch_sphere(
     visualizer_js: Optional[str] = None,
 ):
     r"""
-    Displays a trajectory on the Bloch sphere using state vectors as input.
+    Display a trajectory on the Bloch sphere using state vectors as input.
 
     This function requires IPython, and you must run it from a Jupyter
     notebook. By default, it requires an Internet connection to fetch the
@@ -385,7 +386,7 @@ def display_bloch_sphere_from_density_matrices(
     visualizer_js: Optional[str] = None,
 ):
     r"""
-    Displays a trajectory in the Bloch sphere from input density matrices.
+    Display a trajectory in the Bloch sphere from input density matrices.
 
     This function requires IPython, and you must run it from a Jupyter
     notebook. By default, it requires an Internet connection to fetch the
@@ -497,7 +498,7 @@ def _expectation_values(
     density_matrices: np.ndarray, observables: np.ndarray
 ) -> np.ndarray:
     """
-    Returns expectation values of `observables` for `density_matrices`.
+    Return expectation values of `observables` for `density_matrices`.
 
     Parameters
     ----------
@@ -529,7 +530,7 @@ def display_bloch_sphere_from_bloch_vectors(
     visualizer_js: Optional[str] = None,
 ):
     r"""
-    Displays a Bloch sphere with an animation of the Bloch vectors.
+    Display a Bloch sphere with an animation of the Bloch vectors.
 
     This function requires IPython, and you must run it from a Jupyter
     notebook. By default, it requires an Internet connection to fetch the
@@ -564,7 +565,7 @@ def display_bloch_sphere_from_bloch_vectors(
 
     Raises
     ------
-    ValueError
+    QctrlArgumentsValueError
         If `bloch_vectors` is of complex type.
 
     See Also
@@ -634,8 +635,11 @@ def display_bloch_sphere_from_bloch_vectors(
     qctrlvisualizer-button-replay
         CSS class for the ``<button>`` when the button text is "Replay".
     """
-    if np.iscomplexobj(bloch_vectors):
-        raise ValueError("The Bloch vectors must not have complex type.")
+    check_argument(
+        not np.iscomplexobj(bloch_vectors),
+        "The Bloch vectors must not have complex type.",
+        {"bloch_vectors": bloch_vectors},
+    )
 
     identifier = uuid.uuid4().hex
 
@@ -649,7 +653,7 @@ def display_bloch_sphere_from_bloch_vectors(
                     "z": [vector[2] for vector in bloch_vectors],
                 }
             ]
-        },
+        }
     }
 
     color = color or "#EB6467"
@@ -673,7 +677,7 @@ def _display_visualization(
     visualizer_js: Optional[str] = None,
 ):
     """
-    Calls the Q-CTRL Visualizer JavaScript to display the Bloch sphere.
+    Call the Q-CTRL Visualizer JavaScript to display the Bloch sphere.
 
     You can find the Q-CTRL Visualizer JavaScript package at
     https://www.npmjs.com/package/@qctrl/visualizer .
@@ -723,7 +727,7 @@ def _display_visualization(
     }
 
     default_url = (
-        "https://cdn.jsdelivr.net/npm/@qctrl/visualizer@3.1.11/umd/visualizer.min.js"
+        "https://cdn.jsdelivr.net/npm/@qctrl/visualizer@3.1.14/umd/visualizer.min.js"
     )
 
     # If no custom Visualizer.js is provided, use the default one.
