@@ -22,6 +22,7 @@ from typing import (
 )
 
 import numpy as np
+from qctrlcommons.preconditions import check_argument
 
 from .style import (
     FIG_WIDTH,
@@ -38,7 +39,7 @@ def plot_controls(
     figure, controls, polar=True, smooth=False, unit_symbol="Hz", two_pi_factor=True
 ):
     """
-    Creates a plot of the specified controls.
+    Create a plot of the specified controls.
 
     Parameters
     ----------
@@ -85,10 +86,8 @@ def plot_controls(
 
     Raises
     ------
-    ValueError
+    QctrlArgumentsValueError
         If any of the input parameters are invalid.
-    TypeError
-        If the controls have invalid types.
     """
     boulder_opal_advice = (
         "If you are attempting to plot controls from Boulder Opal, you can obtain"
@@ -97,10 +96,11 @@ def plot_controls(
 
     plots_data: List[Any] = []
 
-    if not isinstance(controls, dict):
-        raise TypeError(
-            f"The `controls` parameter must be a dictionary. {boulder_opal_advice}"
-        )
+    check_argument(
+        isinstance(controls, dict),
+        f"The `controls` parameter must be a dictionary. {boulder_opal_advice}",
+        {"controls": controls},
+    )
 
     for name, control in controls.items():
         # Process each control depending whether it's passed as a list of segments...
@@ -108,30 +108,40 @@ def plot_controls(
             durations = []
             values = []
             for segment in control:
-                if not isinstance(segment, dict):
-                    raise TypeError(
-                        "Each control segment must be a dictionary."
-                        f" {boulder_opal_advice}"
-                    )
-                if ("duration" not in segment) or ("value" not in segment):
-                    raise ValueError(
-                        "Each control segment dictionary must contain `duration` and"
-                        f" `value` keys. {boulder_opal_advice}"
-                    )
+                check_argument(
+                    isinstance(segment, dict),
+                    f"Each control segment must be a dictionary. {boulder_opal_advice}",
+                    {"controls": controls},
+                    extras={"segment": segment},
+                )
+
+                check_argument(
+                    ("duration" in segment) and ("value" in segment),
+                    "Each control segment dictionary must contain `duration` and"
+                    f" `value` keys. {boulder_opal_advice}",
+                    {"controls": controls},
+                    extras={"segment": segment},
+                )
+
                 durations.append(segment["duration"])
                 values.append(segment["value"])
         # ...or a durations/values dictionary.
         else:
-            if not isinstance(control, dict):
-                raise TypeError(
-                    "Each control must either be a list or a dictionary."
-                    f" {boulder_opal_advice}"
-                )
-            if ("durations" not in control) or ("values" not in control):
-                raise ValueError(
-                    "Each control dictionary must contain `durations` and `values`"
-                    f" keys. {boulder_opal_advice}"
-                )
+            check_argument(
+                isinstance(control, dict),
+                f"Each control must either be a list or a dictionary. {boulder_opal_advice}",
+                {"controls": controls},
+                extras={"control": control},
+            )
+
+            check_argument(
+                ("durations" in control) and ("values" in control),
+                "Each control dictionary must contain `durations` and"
+                f" `values` keys. {boulder_opal_advice}",
+                {"controls": controls},
+                extras={"control": control},
+            )
+
             durations = control["durations"]
             values = control["values"]
         # Create plot data for the control.
@@ -213,7 +223,7 @@ def plot_smooth_controls(
     figure, controls, polar=True, unit_symbol="Hz", two_pi_factor=True
 ):
     """
-    Creates a plot of the specified smooth controls.
+    Create a plot of the specified smooth controls.
 
     Parameters
     ----------
@@ -315,7 +325,7 @@ def _create_plots_data_from_control(
     name, xdata, values, polar, unit_symbol, two_pi_factor
 ):
     """
-    Creates a list of _PlotData objects for the given control data.
+    Create a list of _PlotData objects for the given control data.
     """
 
     # Scale values (and name) if they're to be divided by 2π
@@ -371,7 +381,7 @@ def _create_plots_data_from_control(
 @qctrl_style()
 def plot_sequences(figure, seq):
     """
-    Creates plot of dynamical decoupling sequences.
+    Create plot of dynamical decoupling sequences.
 
     Parameters
     ----------
@@ -442,7 +452,7 @@ _PlotSeqData = namedtuple("_PlotSeqData", ["label", "offsets", "rotations"])
 
 def _create_plots_data_from_sequence(name, offsets, rotations):
     """
-    Creates a list of _PlotSeqData objects for the given dynamical decoupling data.
+    Create a list of _PlotSeqData objects for the given dynamical decoupling data.
     """
     if not np.iscomplexobj(rotations):
         return [
