@@ -16,6 +16,7 @@ Functions for plotting filter functions.
 """
 
 import numpy as np
+from qctrlcommons.preconditions import check_argument
 
 from .style import (
     FIG_HEIGHT,
@@ -27,7 +28,7 @@ from .style import (
 @qctrl_style()
 def plot_filter_functions(figure, filter_functions):
     """
-    Creates a plot of the specified filter functions.
+    Create a plot of the specified filter functions.
 
     Parameters
     ----------
@@ -70,11 +71,16 @@ def plot_filter_functions(figure, filter_functions):
 
     Raises
     ------
+    QctrlArgumentsValueError
+        If no filter functions are provided.
     ValueError
-        If any of the input parameters are invalid.
+        If any of the inverse power uncertainties are negative.
     """
-    if not filter_functions:
-        raise ValueError("At least one filter function must be provided")
+    check_argument(
+        filter_functions,
+        "At least one filter function must be provided.",
+        {"filter_functions": filter_functions},
+    )
 
     figure.set_figwidth(FIG_WIDTH)
     figure.set_figheight(FIG_HEIGHT)
